/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

#ifndef SLAMUPDATEDATA_CPP
#define SLAMUPDATEDATA_CPP

#include <stdint.h>
#include <string>
#include <list>
#include <utility>
#include <vector>

#include <xmltio/xmltio.hpp>

#include "../../Type.h"
#include "BinarySlamMap.h"

namespace airobots {

/**
 * Representation of binary slam updates.
 */
class SlamUpdateData: public Type {
public:

	static std::string getBaseTag();

	static std::string getTemplate();

	static std::string getGridTemplate();

	SlamUpdateData();
	SlamUpdateData(std::string generator, bool init = false);

	/**
	 * Data type for lists of updates containing metric coordinates.
	 */
	typedef std::pair<float, float> metricCoord_t;
	typedef std::list<metricCoord_t> list_t;

	/**
	 * Clears all additions and removals.
	 */
	void clear();

	bool isInit() const;
	void setInit(bool init);

	const list_t & getAdditions() const;
	const list_t & getRemovals() const;

	void addAddition(metricCoord_t addition);
	void addRemoval(metricCoord_t removal);

	void addAdditions(list_t::const_iterator begin, list_t::const_iterator end);
	void addRemovals(list_t::const_iterator begin, list_t::const_iterator end);

	void sanitizeLocation(xmltio::Location &loc) const;
	void fillInto(xmltio::Location &loc) const;
	static void fromLocation(const xmltio::Location &loc, SlamUpdateData &type);

private:
	list_t additions;
	list_t removals;

	/**
	 * Tells whether this update contains a complete re-initialization.
	 */
	bool init;

};

}

#endif
