/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

#include "ObjectShapeList.h"

using namespace xmltio;
using namespace airobots;
using namespace std;

std::string ObjectShapeList::getBaseTag() {
	return "OBJECTSHAPELIST";
}

std::string ObjectShapeList::getTemplate() {
	return "<" + getBaseTag() + "></" + getBaseTag() + ">";
}

ObjectShapeList::ObjectShapeList() :
	Type() {
}

ObjectShapeList::ObjectShapeList(std::string generator) :
	Type(generator) {
}

void ObjectShapeList::sanitizeLocation(xmltio::Location &loc) const {
	XPath xp(ObjectShapeData::getBaseTag());
	while (XPathIterator i = xp.evaluate(loc)) {
		Location l(*i);
		loc.remove(l);
	}
}

void ObjectShapeList::fillInto(xmltio::Location &loc) const {

	for (vector<ObjectShapeData>::const_iterator it = this->begin(); it
			!= this->end(); it++) {

		Location obj(ObjectShapeData::getTemplate(), XPath(
				ObjectShapeData::getBaseTag()));

		it->fillInto(obj);
		loc.add(obj);
	}
}

void ObjectShapeList::fromLocation(const xmltio::Location &loc_,
		ObjectShapeList &object) {

	for (XPathIterator iter = XPath(ObjectShapeData::getBaseTag()).evaluate(
			loc_); iter; ++iter) {
		Location l(*iter);
		ObjectShapeData data = extract<ObjectShapeData> (l);
		object.push_back(data);
	}
}

bool ObjectShapeList::operator==(const ObjectShapeList &other) const {

	bool isSame = size() == other.size();
	if (isSame) {
		for (unsigned int i = 0; i < size(); i++) {
			if (!(this->at(i) == other[i])) {
				isSame = false;
			}
		}
	}
	return isSame;
}
