/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

/*
 * Face.h
 *
 *  Created on: Aug 18, 2009
 *      Author: jwienke
 */

#ifndef FACE_H_
#define FACE_H_

#include <iostream>
#include "../../Type.h"
#include "Percept.h"
#include "../../units/UnitConverter.h"

namespace airobots {

/**
 * Face percept representation.
 *
 * @author jwienke
 */
class Face: public Percept {

public:

	static std::string getBaseTag();
	static std::string getTemplate();
	static std::string getPerceptName();

	Face();
	virtual ~Face();

	// TODO units and references?

	float getAngle(AngleUnit angleUnit) const;
	void setAngle(float angle,AngleUnit angleUnit);

	float getHeight(LengthUnit lU) const;
	void setHeight(float height,LengthUnit lU);

	float getDistance(LengthUnit lU) const;
	void setDistance(float distance,LengthUnit lU);

	float getAngleVariance(AngleUnit angleUnit) const;
	void setAngleVariance(float angleVariance,AngleUnit angleUnit);

	float getHeightVariance(LengthUnit lU) const;
	void setHeightVariance(float heightVariance,LengthUnit lU);

	float getDistanceVariance(LengthUnit lU) const;
	void setDistanceVariance(float distanceVariance,LengthUnit lU);

	float getReliability() const;
	void setReliability(float reliability);

	float getFaceWidthAngle(AngleUnit angleUnit) const;
	void setFaceWidthAngle(float faceWidthAngle,AngleUnit angleUnit);

	int getLineOfSight() const;
	void setLineOfSight(int lineOfSight);

	/**
	 * Returns the face x position in pixels (top left corner).
	 */
	unsigned int getImagePositionX() const;
	void setImagePositionX(unsigned int x);

	/**
	 * Returns the face y position in pixels (top left corner).
	 */
	unsigned int getImagePositionY() const;
	void setImagePositionY(unsigned int y);

	/**
	 * Returns the width of the face percept in the image in pixels.
	 */
	unsigned int getImageWidth() const;
	void setImageWidth(unsigned int imageWidth);

	/**
	 * Returns the height of the face percept in the image in pixels.
	 */
	unsigned int getImageHeight() const;
	void setImageHeight(unsigned int imageHeight);

	bool operator==(const Face &other) const;

	void sanitizeLocation(xmltio::Location &loc) const;
	void fillInto(xmltio::Location &loc) const;
	static void fromLocation(const xmltio::Location &loc, Face &type);

private:

	float angle;
	float angleVariance;
	float height;
	float heightVariance;
	float distance;
	float distanceVariance;
	float reliability;
	float faceWidthAngle;
	int lineOfSight;
	unsigned int imagePositionX;
	unsigned int imagePositionY;
	unsigned int imageWidth;
	unsigned int imageHeight;

	static const LengthUnit iLU = MILLIMETER;
	static const AngleUnit iAU = RADIAN;

};

std::ostream& operator<<(std::ostream& o, Face const& face);

}

#endif /* FACE_H_ */
