/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

#ifndef PlaneDATA_H_
#define PlaneDATA_H_

#include <string>

#include <xmltio/xmltio.hpp>

#include "../vision2d/RegionData.h"
#include "../geometry/Point3D.h"
#include "../geometry/Rotation3D.h"

namespace airobots {

/**
 * This class describes an arbitrary shaped plane in a 3d space. The plane's shape is described by a
 * polygon in the x-y-layer plus a translation and rotation rule. To obtain the real 3d coordinates
 * of the given points, you will have to add a zero in the third dimension (as the polygon describes
 * the shape in the x-y-layer), rotate the points with the normal rotation angles and translate the
 * resulting points with the given translation values.
 *
 * @author lziegler
 */
class PlaneData: public RegionData {

public:

	static std::string getBaseTag();
	static std::string getTemplate();

	virtual bool operator==(const PlaneData &other) const;

	void sanitizeLocation(xmltio::Location&) const;
	void fillInto(xmltio::Location &loc) const;
	static void fromLocation(const xmltio::Location &loc, PlaneData &type);

	PlaneData();
	PlaneData(const PlaneData &data);
	PlaneData(std::string generator);

	void setOrigin(const Point3D origin);
	Point3D getOrigin() const;

	void setRotation(const Rotation3D rotation);
	Rotation3D getRotation() const;

private:
	Point3D origin;
	Rotation3D rotation;
};

}

#endif /* PlaneDATA_H_ */
