/*
 * This file is part of Bielefeld Type Library (BTL).
 * 
 * Copyright(c) Frederic Siepmann http://opensource.cit-ec.de/projects/btl
 * 
 * This file may be licensed under the terms of of the GNU Lesser General Public
 * License Version 3 (the ``LGPL''), or (at your option) any later version.
 * 
 * Software distributed under the License is distributed on an ``AS IS'' basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the LGPL for the
 * specific language governing rights and limitations.
 * 
 * You should have received a copy of the LGPL along with this program. If not,
 * go to http://www.gnu.org/licenses/lgpl.html or write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 * 
 * The development of this software was supported by the Excellence Cluster EXC
 * 277 Cognitive Interaction Technology. The Excellence Cluster EXC 277 is a
 * grant of the Deutsche Forschungsgemeinschaft (DFG) in the context of the
 * German Excellence Initiative.
 * 
 * Contributors: Florian Lier, Frederic Siepmann, Leon Ziegler, Matthias 
 * Schoepfer, Adriana-Victoria Dreyer, Agnes Swadzba, Andreas Kipp, Birte 
 * Carlmeyer, Christian Ascheberg, Daniel Nacke, Dennis Wigand, Günes Minareci, 
 * Hendrik ter Horst, Ingo Killmann, Jan Pöppel, Lukas Kettenbach, Michael 
 * Zeunert, Patrick Renner, Philipp Dresselhaus, Robin Schiewer, Sebastian 
 * Meyer zu Borgsen, Soufian Jebbara, Tobias Röhlig, Torben Toeniges, Tristan 
 * Walter, Viktor Losing, Viktor Richter
 */
package de.unibi.airobots.btl.data.annotation;

import de.unibi.airobots.btl.Type;
import de.unibi.airobots.btl.data.navigation.NavigationGoalData;
import de.unibi.airobots.btl.data.object.ObjectData;
import de.unibi.airobots.btl.units.LengthUnit;
import de.unibi.airobots.btl.units.UnitConverter;
import nu.xom.Attribute;
import nu.xom.Element;
import nu.xom.Nodes;

import org.apache.log4j.Logger;
import de.unibi.airobots.btl.data.map.Annotation;

/**
 * 
 * @author jhelbach
 * 
 * @deprecated Use {@link Annotation} instead.
 */
@Deprecated
public class MapPoint extends Type {

	private static final String BASETAG = "MAPPOINT";

	private static final String POINT_TAG = "Point";

	private static final String KIND_TAG = "Kind";

	/**
	 * The Logger.
	 */
	private Logger logger = Logger.getLogger(this.getClass());

	private double x;

	private double y;

	private MapPoint.Kind kind;

	private MapPoint.Unit unit = Unit.M;

	private String ref;

	private LengthUnit iLU = LengthUnit.METER;
	
	public MapPoint() {
		
	}

	public MapPoint(double x, double y, LengthUnit lU) {
		this.x = UnitConverter.convert(x, lU, iLU);
		this.y = UnitConverter.convert(y, lU, iLU);
		ref = "";
		kind = MapPoint.Kind.WORLD;
		switch (lU) {
		case CENTIMETER:
			unit = Unit.CM;
			break;
		case METER:
			unit = Unit.M;
			break;
		case MILLIMETER:
			unit = Unit.MM;
			break;
		default:
			unit = Unit.M;
			logger.warn("Length parameter deprecated!");
		}
		iLU = lU;
	}

	public MapPoint(double x, double y, MapPoint.Kind kind, LengthUnit lU,
			String ref) {
		super();
		this.x = UnitConverter.convert(x, lU, iLU);
		this.y = UnitConverter.convert(y, lU, iLU);
		this.kind = kind;
		this.ref = ref;
		switch (lU) {
		case CENTIMETER:
			unit = Unit.CM;
			break;
		case METER:
			unit = Unit.M;
			break;
		case MILLIMETER:
			unit = Unit.MM;
			break;
		default:
			unit = Unit.M;
			logger.warn("Length parameter deprecated!");
		}
		iLU = lU;
	}

	public MapPoint(MapPoint p) {
		this.x = p.getX(iLU);
		this.y = p.getY(iLU);
		this.kind = p.getKind();
		this.ref = p.getRef();
	}

	public double getX(LengthUnit lU) {
		return UnitConverter.convert(x, iLU, lU);
	}

	public void setX(double x, LengthUnit lU) {
		this.x = UnitConverter.convert(x, lU, iLU);
	}

	public double getY(LengthUnit lU) {
		return UnitConverter.convert(y, iLU, lU);
	}

	public void setY(double y, LengthUnit lU) {
		this.y = UnitConverter.convert(y, lU, iLU);
	}

	public MapPoint.Kind getKind() {
		return kind;
	}

	public void setKind(MapPoint.Kind kind) {
		this.kind = kind;
	}

	@Deprecated
	public MapPoint.Unit getUnit() {
		return unit;
	}

	public LengthUnit getLengthUnit() {
		return iLU;
	}

	@Deprecated
	public void setUnit(MapPoint.Unit unit) {
		this.unit = unit;
	}

	public void setLengthUnit(LengthUnit iLU) {
		this.iLU = iLU;
	}

	public String getRef() {
		return ref;
	}

	public void setRef(String ref) {
		this.ref = ref;
	}

	public enum Unit {
		M, CM, MM, NM
	}

	public enum Kind {
		WORLD, RELATIVE
	}
	
	public static String getBaseTag() {
		return BASETAG;
	}

	/**
	 * Fills an {@link ObjectData} object from a given XOM {@link Element}.
	 * 
	 * @param objectElement
	 *            The XOM {@link Element} to fill an object from.
	 * @param type
	 *            The {@link ObjectData} object to fill with all the information
	 *            given by the {@link Element} object.
	 */
	public static void fromElement(Element objectElement, MapPoint type) {

		Type.fromElement(objectElement, type);

		try {

			Element p = objectElement.getFirstChildElement(POINT_TAG);
			Element k = objectElement.getFirstChildElement(KIND_TAG);

			type.x = Double.parseDouble(p.getAttribute("x").getValue());
			type.y = Double.parseDouble(p.getAttribute("y").getValue());
			type.kind = Kind.valueOf(k.getValue());

		} catch (NullPointerException ex) {
			// this happens when an element or attribute that is required is
			// not present
			throw new IllegalArgumentException("Missing element or attribute "
					+ "in document.", ex);
		} catch (NumberFormatException e) {
			throw new IllegalArgumentException("Can not parse number", e);
		}
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public void sanitizeElement(Element parent) {

		super.sanitizeElement(parent);

		Nodes nodes = parent.query(POINT_TAG);
		for (int i = 0; i < nodes.size(); i++) {
			parent.removeChild(nodes.get(i));
		}
		nodes = parent.query(KIND_TAG);
		for (int i = 0; i < nodes.size(); i++) {
			parent.removeChild(nodes.get(i));
		}
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public void fillInto(Element parent) {

		sanitizeElement(parent);

		super.fillInto(parent);

		Element pointName = new Element(POINT_TAG);
		pointName.addAttribute(new Attribute("x", String.valueOf(x)));
		pointName.addAttribute(new Attribute("y", String.valueOf(y)));
		Element kindName = new Element(KIND_TAG);
		kindName.appendChild(kind.name());

		parent.appendChild(pointName);
		parent.appendChild(kindName);
	}

}
