/*
 * This file is part of Bielefeld Type Library (BTL).
 * 
 * Copyright(c) Frederic Siepmann http://opensource.cit-ec.de/projects/btl
 * 
 * This file may be licensed under the terms of of the GNU Lesser General Public
 * License Version 3 (the ``LGPL''), or (at your option) any later version.
 * 
 * Software distributed under the License is distributed on an ``AS IS'' basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the LGPL for the
 * specific language governing rights and limitations.
 * 
 * You should have received a copy of the LGPL along with this program. If not,
 * go to http://www.gnu.org/licenses/lgpl.html or write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 * 
 * The development of this software was supported by the Excellence Cluster EXC
 * 277 Cognitive Interaction Technology. The Excellence Cluster EXC 277 is a
 * grant of the Deutsche Forschungsgemeinschaft (DFG) in the context of the
 * German Excellence Initiative.
 * 
 * Contributors: Florian Lier, Frederic Siepmann, Leon Ziegler, Matthias 
 * Schoepfer, Adriana-Victoria Dreyer, Agnes Swadzba, Andreas Kipp, Birte 
 * Carlmeyer, Christian Ascheberg, Daniel Nacke, Dennis Wigand, Günes Minareci, 
 * Hendrik ter Horst, Ingo Killmann, Jan Pöppel, Lukas Kettenbach, Michael 
 * Zeunert, Patrick Renner, Philipp Dresselhaus, Robin Schiewer, Sebastian 
 * Meyer zu Borgsen, Soufian Jebbara, Tobias Röhlig, Torben Toeniges, Tristan 
 * Walter, Viktor Losing, Viktor Richter
 */
package de.unibi.airobots.btl.data.asu;

import nu.xom.Element;
import nu.xom.ParsingException;
import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;

/**
 *
 * @author divine
 */
public class Slot {

	private final FrameEntry frame;
	private final boolean optional;

	public Slot(FrameEntry frame, boolean isOptional) {
		this.frame = frame;
		this.optional = isOptional;
	}

	public Slot(final Element slotElement, final FrameDB frameDB) throws ParsingException {
		String frameName = slotElement.getAttributeValue("name");
		if (frameName.isEmpty()) {
			throw new ParsingException("Slot frame name is empty!");
		}
		boolean optionalValue;
		try {
			optionalValue = Boolean.parseBoolean(slotElement.getAttributeValue("optional"));
		} catch(Exception ex) {
			optionalValue = false;
		}
		this.optional = optionalValue;
		this.frame = frameDB.getFrame(frameName);
	}

	public FrameEntry getFrame() {
		return frame;
	}

	public String getName() {
		return frame.getName();
	}

	public boolean isOptional() {
		return optional;
	}

	@Override
	public int hashCode() {
		return new HashCodeBuilder(17, 31). // two randomly chosen prime numbers
				append(getName()).
				toHashCode();
	}

	@Override
	public boolean equals(Object obj) {
		if (obj == null) {
			return false;
		}
		if (obj == this) {
			return true;
		}
		if (obj.getClass() != getClass()) {
			return false;
		}

		Slot slotEntry = (Slot) obj;
		return new EqualsBuilder().
				append(getName(), slotEntry.getName()).
				isEquals();
	}

	public int compareTo(Slot o) {
		return getName().compareTo(o.getName());
	}
}
