/*
 * This file is part of Bielefeld Type Library (BTL).
 * 
 * Copyright(c) Frederic Siepmann http://opensource.cit-ec.de/projects/btl
 * 
 * This file may be licensed under the terms of of the GNU Lesser General Public
 * License Version 3 (the ``LGPL''), or (at your option) any later version.
 * 
 * Software distributed under the License is distributed on an ``AS IS'' basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the LGPL for the
 * specific language governing rights and limitations.
 * 
 * You should have received a copy of the LGPL along with this program. If not,
 * go to http://www.gnu.org/licenses/lgpl.html or write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 * 
 * The development of this software was supported by the Excellence Cluster EXC
 * 277 Cognitive Interaction Technology. The Excellence Cluster EXC 277 is a
 * grant of the Deutsche Forschungsgemeinschaft (DFG) in the context of the
 * German Excellence Initiative.
 * 
 * Contributors: Florian Lier, Frederic Siepmann, Leon Ziegler, Matthias 
 * Schoepfer, Adriana-Victoria Dreyer, Agnes Swadzba, Andreas Kipp, Birte 
 * Carlmeyer, Christian Ascheberg, Daniel Nacke, Dennis Wigand, Günes Minareci, 
 * Hendrik ter Horst, Ingo Killmann, Jan Pöppel, Lukas Kettenbach, Michael 
 * Zeunert, Patrick Renner, Philipp Dresselhaus, Robin Schiewer, Sebastian 
 * Meyer zu Borgsen, Soufian Jebbara, Tobias Röhlig, Torben Toeniges, Tristan 
 * Walter, Viktor Losing, Viktor Richter
 */
package de.unibi.airobots.btl.data.object;

import nu.xom.Attribute;
import nu.xom.Element;
import nu.xom.Node;
import nu.xom.Nodes;
import nu.xom.ParsingException;

import org.apache.log4j.Logger;

import de.unibi.airobots.btl.Type;
import de.unibi.airobots.btl.data.common.ElementParser;

/**
 * This class is used to store an objectName with the orderer of it. * 
 * @author vlosing
 */
public class ObjectOrder extends Type {

	private static Logger logger = Logger.getLogger(ObjectOrder.class);

	private String objectName = "";
	private String ordererName = "";
	
	private static String ATTR_OBJECT_NAME = "OBJECTNAME";
	private static String ATTR_ORDERER_NAME = "ORDERERNAME";	
	
	/**
	 * @return ojbectName
	 */
	public String getObjectName() {
		return objectName;
	}
	
	/**
	 * @return orderName
	 */
	public String getOrdererName() {
		return ordererName;
	}	

	/**
	 * Sets the object name.
	 * 
	 * @param objectName
	 *            name of object
	 */
	public void setObjectName(String objectName) {
		this.objectName = objectName;
	}

	/**
	 * Sets the object name.
	 * 
	 * @param objectName
	 *            name of object
	 */
	public void setOrdererName(String ordererName) {
		this.ordererName = ordererName;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String toString() {
		StringBuilder strb = new StringBuilder();
		strb.append("#ObjectOrder# ");
		strb.append("objectName: " + getObjectName() + "; ");
		strb.append("ordererName: " + getOrdererName() + "; ");
		return strb.toString();
	}

	public static String getBaseTag() {
		return "OBJECTORDER";
	}

	public static void fromElement(Element element, ObjectOrder type)
			throws ParsingException {

		logger.debug("fromElement called");
		
		Type.fromElement(element, type);

		type.setObjectName(ElementParser.getAttributeValue(element, ATTR_OBJECT_NAME));
		type.setOrdererName(ElementParser.getAttributeValue(element, ATTR_ORDERER_NAME));		
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public void fillInto(Element parent) {

		super.fillInto(parent);
		
		parent.addAttribute(new Attribute(ATTR_OBJECT_NAME, getObjectName()));		
		parent.addAttribute(new Attribute(ATTR_ORDERER_NAME, getOrdererName()));		
	}
}
