/*
 * This file is part of Bielefeld Type Library (BTL).
 *
 * Copyright(c) Frederic Siepmann
 * http://opensource.cit-ec.de/projects/btl
 *
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 *
 * Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
 * 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
 * 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
 */
package de.unibi.airobots.btl.data.annotation;

import static org.junit.Assert.*;
import nu.xom.Builder;
import nu.xom.Document;
import nu.xom.Element;

import org.apache.log4j.Logger;
import org.junit.Test;

import de.unibi.airobots.btl.TestUtils;
import de.unibi.airobots.btl.Type;
import de.unibi.airobots.btl.data.annotation.MapPoint.Kind;
import de.unibi.airobots.btl.data.common.Timestamp;
import de.unibi.airobots.btl.data.object.ObjectData;
import de.unibi.airobots.btl.units.LengthUnit;

/**
 * Test cases for {@link Type}.
 * 
 * @author lziegler
 */
public class MapPointTest {

	private Logger logger = Logger.getLogger(getClass());

	@Test
	public void selfCompatibility() throws Exception {

		MapPoint original = new MapPoint(0.4, 4.6, LengthUnit.METER);

		Element doc = new Element(MapPoint.getBaseTag());
		original.fillInto(doc);
		logger.info(doc.toXML());

		MapPoint parsed = new MapPoint();
		MapPoint.fromElement(doc, parsed);

		assertEquals(original.getX(LengthUnit.METER),
				parsed.getX(LengthUnit.METER), 0.0001);
		assertEquals(original.getY(LengthUnit.METER),
				parsed.getY(LengthUnit.METER), 0.0001);
		assertEquals(original.getKind(), parsed.getKind());

	}

	@Test
	public void fileCompatibility() throws Exception {

		Builder parser = new Builder();
		Document doc = parser.build(TestUtils
				.makeTestFileName("MapPoint.xml"));

		MapPoint parsed = new MapPoint();
		MapPoint.fromElement(doc.getRootElement(), parsed);

		assertEquals(doc.getRootElement().getLocalName(),
				MapPoint.getBaseTag());

		assertEquals(0.4, parsed.getX(LengthUnit.METER), 0.0001);
		assertEquals(4.6, parsed.getY(LengthUnit.METER), 0.0001);
		assertEquals(Kind.WORLD, parsed.getKind());

	}

}
