/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/
package de.unibi.airobots.btl.data.asu;

import org.junit.Test;

import de.unibi.airobots.btl.TestUtils;
import static org.junit.Assert.*;

/**
 * Tests the frame database.
 * 
 * @author malinke
 */
public final class FrameDBTest {

	private FrameDB db = new FrameDB(TestUtils.makeTestFileName("frames.xml"));

	/**
	 * Test of getFrame method, of class FrameDBOld.
	 */
	@Test
	public void testGetFrame() throws Exception {
		String frameName = "Modality";
		FrameEntry modality = db.getFrame(frameName);
		assertNotNull(modality);
		assertEquals(frameName, modality.getName());
		assertEquals(frameName, modality.getTopName());
		String emptyName = "";
		FrameEntry empty = db.getFrame(emptyName);
		assertNotNull(empty);
		assertFalse(modality.slotList().contains(empty));
		frameName = "Name_personal";
		FrameEntry namePersonal = db.getFrame(frameName);
		assertNotNull(namePersonal);
		assertFalse(namePersonal.slotList().contains(empty));
		FrameEntry questionObject = db.getFrame("Question_object");
		final int numberOfRelated = 4;
		assertEquals(numberOfRelated, questionObject.slotList().size());
	}
}