/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/
package de.unibi.airobots.btl.data.asu;

import java.util.List;
import org.junit.Test;
import static org.junit.Assert.*;

/**
 * Tests FrameEntry.
 * 
 * @author malinke
 */
public final class FrameEntryTest {

	/**
	 * Test of getName method, of class FrameEntry.
	 */
	@Test
	public void testGetName() {
		String name = "ASU";
		FrameEntry frame = new FrameEntry(name);
		assertEquals(name, frame.getName());
	}

	/**
	 * Test of getTopName method, of class FrameEntry.
	 */
	@Test
	public void testGetTopName() {
		String name = "ASU";
		FrameEntry frame = new FrameEntry(name);
		frame.setTopFrame(frame);
		assertEquals(name, frame.getTopName());
	}

	/**
	 * Test of slotList method, of class FrameEntry.
	 */
	@Test
	public void testAllRelatedFrames() throws Exception {
		FrameEntry root = new FrameEntry("0");
		Slot child1 = new Slot(new FrameEntry("1"), false);
		Slot child2 = new Slot(new FrameEntry("2"), false);
		root.addSlot(child1);
		root.addSlot(child2);
		List<Slot> allRelated = root.slotList();
		assertEquals(2, allRelated.size());
		assertEquals(child1, allRelated.get(0));
		assertEquals(child2, allRelated.get(1));
	}

	/**
	 * Tests comparison with more general frames.
	 */
	@Test
	public void testIsTypeOf() {
		FrameEntry polygon = new FrameEntry("polygon");
		FrameEntry rectangle = new FrameEntry("rectangle");
		FrameEntry square = new FrameEntry("square");
		rectangle.setTopFrame(polygon);
		square.setTopFrame(rectangle);
		assertTrue(square.isOfType(square));
		assertFalse(rectangle.isOfType(square));
		assertTrue(square.isOfType(rectangle));
		assertTrue(square.isOfType(polygon));
	}

}