/*
 * This file is part of Bielefeld Type Library (BTL).
 *
 * Copyright(c) Frederic Siepmann
 * http://opensource.cit-ec.de/projects/btl
 *
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 *
 * Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
 * 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
 * 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
 */
package de.unibi.airobots.btl.data.geometry;

import static org.junit.Assert.*;
import nu.xom.Element;

import org.junit.Test;

import de.unibi.airobots.btl.data.geometry.Point2D;
import de.unibi.airobots.btl.data.geometry.Point2D.Scope;
import de.unibi.airobots.btl.units.LengthUnit;

/**
 * Test cases for {@link Type}.
 * 
 * @author lziegler
 */
public class Point2DTest {

	@Test
	public void selfCompatibility() throws Exception {

		Point2D p0 = new Point2D(1, 2, LengthUnit.MILLIMETER, Scope.GLOBAL);
		Point2D p1 = new Point2D(1, 2, LengthUnit.MILLIMETER, Scope.GLOBAL);
		Point2D p2 = new Point2D(0.1, 0.2, LengthUnit.MILLIMETER, Scope.LOCAL);

		assertTrue("equals() not working", p0.equals(p1));
		assertTrue("equals() not working", p1.equals(p0));

		assertFalse("equals() not working", p1.equals(p2));

		assertEquals("Conversion not working", p2.getX(LengthUnit.MILLIMETER),
				p2.getX(LengthUnit.METER) * 1000, 0.00001);
		assertEquals("Conversion not working", p2.getY(LengthUnit.MILLIMETER),
				p2.getY(LengthUnit.METER) * 1000, 0.00001);
		assertEquals("Conversion not working", p2.getX(LengthUnit.MILLIMETER),
				p2.getX(LengthUnit.CENTIMETER) * 10, 0.00001);
		assertEquals("Conversion not working", p2.getY(LengthUnit.MILLIMETER),
				p2.getY(LengthUnit.CENTIMETER) * 10, 0.00001);

		Element element = new Element(Point2D.getBaseTag());
		p0.fillInto(element);

		Point2D p3 = new Point2D();
		Point2D.fromElement(element, p3);

		assertTrue("serializing not working", p0.equals(p3));
	}
}
