/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/
package de.unibi.airobots.btl.data.hardwareinfo;

import org.apache.log4j.BasicConfigurator;
import org.junit.Test;

import de.unibi.airobots.btl.data.hardwareinfo.LaserInfo;
import de.unibi.airobots.btl.data.hardwareinfo.LaserInfo.OutOfRangeException;
import de.unibi.airobots.btl.data.hardwareinfo.LaserInfo.ScannerModel;
import static org.junit.Assert.*;

public class LaserInfoTest {

	@Test
	public void testGetScanNum() throws OutOfRangeException {
		BasicConfigurator.configure();

		assertEquals(0, LaserInfo.calcScanIndex(ScannerModel.SICK_LMS200, -Math.PI / 2.0));
		assertEquals(360, LaserInfo.calcScanIndex(ScannerModel.SICK_LMS200, Math.PI / 2.0));
		assertEquals(180, LaserInfo.calcScanIndex(ScannerModel.SICK_LMS200, 0));
		
		assertEquals(0, LaserInfo.calcScanIndex(ScannerModel.SICK_LMS200, -Math.PI / 2.0 + 0.0001));
		assertEquals(360, LaserInfo.calcScanIndex(ScannerModel.SICK_LMS200, Math.PI / 2.0 - 0.0001));
		
		double nextAngle = -Math.PI / 2.0 + (0.5 * Math.PI / 180.0);
		assertEquals(1, LaserInfo.calcScanIndex(ScannerModel.SICK_LMS200, nextAngle));
		assertEquals(1, LaserInfo.calcScanIndex(ScannerModel.SICK_LMS200, nextAngle - 0.0001));
		
		double prevAngle = Math.PI / 2.0 - (0.5 * Math.PI / 180.0);
		assertEquals(359, LaserInfo.calcScanIndex(ScannerModel.SICK_LMS200, prevAngle));
		assertEquals(359, LaserInfo.calcScanIndex(ScannerModel.SICK_LMS200, prevAngle + 0.0001));
		
		try {
			LaserInfo.calcScanIndex(ScannerModel.SICK_LMS200, Math.PI);
			fail();
		} catch (Exception e) {
			// every thing ok
		}
	}
}
