/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/
package de.unibi.airobots.btl.data.navigation;

import static org.junit.Assert.*;
import nu.xom.Document;
import nu.xom.Element;
import org.apache.log4j.Logger;
import org.junit.Test;


/**
 * Test cases for {@link ROSCostmapConfiguration}
 * 
 * @author pdressel
 */
public class ROSCostmapConfigurationTest {
    
    private final static Double DELTA = 0.0001;
    private Logger logger = Logger.getLogger(getClass());
        
    public static ROSCostmapConfiguration createMockObject() {
        
        ROSCostmapConfiguration costmapConfiguration = new ROSCostmapConfiguration();
        costmapConfiguration.setCostScalingFactor(Math.random());
        costmapConfiguration.setFootprint("[[-1.0,1.0],[1.0,1.0],[1.0,-1.0],[-1.0,-1.0]]");
        costmapConfiguration.setHeight((int)Math.random());
        costmapConfiguration.setInflationRadius(Math.random());
        costmapConfiguration.setIsGlobalCostmap(Math.random() > Math.random());
        costmapConfiguration.setLethalCostThreshold((int)Math.random());
        costmapConfiguration.setMapTopic("map");
        costmapConfiguration.setMapType("costmap");
        costmapConfiguration.setMarkThreshold((int)Math.random());
        costmapConfiguration.setMaxObstacleHeight(Math.random());
        costmapConfiguration.setMaxObstacleRange(Math.random());
        costmapConfiguration.setOriginX(Math.random());
        costmapConfiguration.setOriginY(Math.random());
        costmapConfiguration.setPublishFrequency(Math.random());
        costmapConfiguration.setPublishVoxelMap(Math.random() > Math.random());
        costmapConfiguration.setRaytraceRange(Math.random());
        costmapConfiguration.setResolution(Math.random());
        costmapConfiguration.setRestoreDefaults(Math.random() > Math.random());
        costmapConfiguration.setRobotRadius(Math.random());
        costmapConfiguration.setRollingWindow(Math.random() > Math.random());
        costmapConfiguration.setStaticMap(Math.random() > Math.random());
        costmapConfiguration.setTrackUnknownSpace(Math.random() > Math.random());
        costmapConfiguration.setTransformTolerance(Math.random());
        costmapConfiguration.setUnknownCostValue((int)Math.random());
        costmapConfiguration.setUnknownThreshold((int)Math.random());
        costmapConfiguration.setUpdateFrequency(Math.random());
        costmapConfiguration.setWidth((int)Math.random());
        costmapConfiguration.setzOrigin(Math.random());
        costmapConfiguration.setzResolution(Math.random());
        costmapConfiguration.setzVoxels((int)Math.random());
        
        return costmapConfiguration;
    }
    
    
    @Test
    public void selfCompatibility() throws Exception {
        
        ROSCostmapConfiguration original = createMockObject();
        ROSCostmapConfiguration parsed = new ROSCostmapConfiguration();
        
        Document doc = new Document(new Element(ROSCostmapConfiguration.getBaseTag()));
        original.fillInto(doc.getRootElement());
        logger.info(doc.toXML());
        
        ROSCostmapConfiguration.fromElement(doc.getRootElement(), parsed);
        
        assertEquals(original.getCostScalingFactor(), parsed.getCostScalingFactor(), DELTA);
        assertEquals(original.getFootprint(), parsed.getFootprint());
        assertEquals(original.getHeight(), parsed.getHeight());
        assertEquals(original.getInflationRadius(), parsed.getInflationRadius(), DELTA);
        assertEquals(original.isIsGlobalCostmap(), parsed.isIsGlobalCostmap());
        assertEquals(original.getLethalCostThreshold(), parsed.getLethalCostThreshold());
        assertEquals(original.getMapTopic(), parsed.getMapTopic());
        assertEquals(original.getMapType(), parsed.getMapType());
        assertEquals(original.getMarkThreshold(), parsed.getMarkThreshold());
        assertEquals(original.getMaxObstacleHeight(), parsed.getMaxObstacleHeight(), DELTA);
        assertEquals(original.getMaxObstacleRange(), parsed.getMaxObstacleRange(), DELTA);
        assertEquals(original.getOriginX(), parsed.getOriginX(), DELTA);
        assertEquals(original.getOriginY(), parsed.getOriginY(), DELTA);
        assertEquals(original.getPublishFrequency(), parsed.getPublishFrequency(), DELTA);
        assertEquals(original.isPublishVoxelMap(), parsed.isPublishVoxelMap());
        assertEquals(original.getRaytraceRange(), parsed.getRaytraceRange(), DELTA);
        assertEquals(original.getResolution(), parsed.getResolution(), DELTA);
        assertEquals(original.isRestoreDefaults(), parsed.isRestoreDefaults());
        assertEquals(original.getRobotRadius(), parsed.getRobotRadius(), DELTA);
        assertEquals(original.isRollingWindow(), parsed.isRollingWindow());
        assertEquals(original.isStaticMap(), parsed.isStaticMap());
        assertEquals(original.isTrackUnknownSpace(), parsed.isTrackUnknownSpace());
        assertEquals(original.getTransformTolerance(), parsed.getTransformTolerance(), DELTA);
        assertEquals(original.getUnknownCostValue(), parsed.getUnknownCostValue());
        assertEquals(original.getUnknownThreshold(), parsed.getUnknownThreshold());
        assertEquals(original.getUpdateFrequency(), parsed.getUpdateFrequency(), DELTA);
        assertEquals(original.getWidth(), parsed.getWidth());
        assertEquals(original.getzOrigin(), parsed.getzOrigin(), DELTA);
        assertEquals(original.getzResolution(), parsed.getzResolution(), DELTA);
        assertEquals(original.getzVoxels(), parsed.getzVoxels());
    }
}
