/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/
package de.unibi.airobots.btl.data.object;

import static org.junit.Assert.assertEquals;
import nu.xom.Builder;
import nu.xom.Document;
import nu.xom.Element;
import nu.xom.ParsingException;

import org.apache.log4j.Logger;
import org.junit.Test;

import de.unibi.airobots.btl.TestUtils;
import de.unibi.airobots.btl.Type;
import de.unibi.airobots.btl.data.geometry.Point2D;
import de.unibi.airobots.btl.data.geometry.Point3D;
import de.unibi.airobots.btl.units.LengthUnit;

/**
 * Test cases for {@link Type}.
 * 
 * @author lziegler <lziegler@techfak.uni-bielefeld.de>
 */
public class DoorTest {

	private Logger logger = Logger.getLogger(getClass());

	@Test
	public void selfCompatibility() throws ParsingException {

		Door original = new Door();
		final long timestamp = System.currentTimeMillis();
		original.setTimestamp(timestamp);
		original.setDoorLeft(new Point2D(1.0, 2.0, LengthUnit.METER));
		original.setDoorRight(new Point2D(3.0, 4.0, LengthUnit.METER));
		original.setHandleLeft(new Point3D(5.0, 6.0, 7.0, LengthUnit.METER));
		original.setHandleRight(new Point3D(8.0, 9.0, 0.0, LengthUnit.METER));

		Document document = new Document(new Element(Door.getBaseTag()));
		original.fillInto(document.getRootElement());

		logger.info(document.toXML());

		Door parsed = new Door();
		Door.fromElement(document.getRootElement(), parsed);

		LengthUnit u = LengthUnit.METER;
		assertEquals(original.getDoorLeft().getX(u), parsed.getDoorLeft().getX(u), 0.0001);
		assertEquals(original.getDoorLeft().getY(u), parsed.getDoorLeft().getY(u), 0.0001);
		assertEquals(original.getDoorRight().getX(u), parsed.getDoorRight().getX(u), 0.0001);
		assertEquals(original.getDoorRight().getY(u), parsed.getDoorRight().getY(u), 0.0001);
		assertEquals(original.getHandleLeft().getX(u), parsed.getHandleLeft().getX(u), 0.0001);
		assertEquals(original.getHandleLeft().getY(u), parsed.getHandleLeft().getY(u), 0.0001);
		assertEquals(original.getHandleRight().getX(u), parsed.getHandleRight().getX(u), 0.0001);
		assertEquals(original.getHandleRight().getY(u), parsed.getHandleRight().getY(u), 0.0001);
		assertEquals(original.getCoordinateSystem(), parsed.getCoordinateSystem());
	}

	@Test
	public void fileCompatibility() throws Exception {
		
		Door original = new Door();
		final long timestamp = System.currentTimeMillis();
		original.setTimestamp(timestamp);
		original.setDoorLeft(new Point2D(1.0, 2.0, LengthUnit.METER));
		original.setDoorRight(new Point2D(3.0, 4.0, LengthUnit.METER));
		original.setHandleLeft(new Point3D(5.0, 6.0, 7.0, LengthUnit.METER));
		original.setHandleRight(new Point3D(8.0, 9.0, 0.0, LengthUnit.METER));

		Builder parser = new Builder();
		Document doc = parser.build(TestUtils.makeTestFileName("Door.xml"));

		Door parsed = new Door();
		Door.fromElement(doc.getRootElement(), parsed);

		assertEquals(doc.getRootElement().getLocalName(), Door.getBaseTag());
		assertEquals("test", parsed.getGenerator());
		LengthUnit u = LengthUnit.METER;
		assertEquals(original.getDoorLeft().getX(u), parsed.getDoorLeft().getX(u), 0.0001);
		assertEquals(original.getDoorLeft().getY(u), parsed.getDoorLeft().getY(u), 0.0001);
		assertEquals(original.getDoorRight().getX(u), parsed.getDoorRight().getX(u), 0.0001);
		assertEquals(original.getDoorRight().getY(u), parsed.getDoorRight().getY(u), 0.0001);
		assertEquals(original.getHandleLeft().getX(u), parsed.getHandleLeft().getX(u), 0.0001);
		assertEquals(original.getHandleLeft().getY(u), parsed.getHandleLeft().getY(u), 0.0001);
		assertEquals(original.getHandleRight().getX(u), parsed.getHandleRight().getX(u), 0.0001);
		assertEquals(original.getHandleRight().getY(u), parsed.getHandleRight().getY(u), 0.0001);
		assertEquals(original.getCoordinateSystem(), parsed.getCoordinateSystem());

	}

}
