/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke,
* 				Dennis Leroy Wigand
*/
package de.unibi.airobots.btl.data.person;

import static org.junit.Assert.*;
import nu.xom.Builder;
import nu.xom.Document;
import nu.xom.Element;

import org.apache.log4j.Logger;
import org.junit.Test;

import de.unibi.airobots.btl.TestUtils;
import de.unibi.airobots.btl.Type;
import de.unibi.airobots.btl.data.geometry.Point3D;
import de.unibi.airobots.btl.data.person.Body;
import de.unibi.airobots.btl.units.*;

/**
 * Test cases for {@link Type}.
 * 
 * @author Dennis Leroy Wigand <dwigand@techfak.uni-bielefeld.de>
 */
public class BodyTest {

	private Logger logger = Logger.getLogger(getClass());

	@Test
	public void selfCompatibility() {

		Body original = new Body();
		final long timestamp = System.currentTimeMillis();
		original.setTimestamp(timestamp);
		original.setKinectId(5);
		original.setCoM(new Point3D(1,2,3,LengthUnit.MILLIMETER));
		original.setTorso(new Point3D(4,5,6,LengthUnit.MILLIMETER));
		original.setGenerator("DLWTest");
		original.setSkeleton(true);
		
		Document document = new Document(new Element(Body.getBaseTag()));
		original.fillInto(document.getRootElement());

		logger.info(document.toXML());

		Body parsed = new Body();
		Body.fromElement(document.getRootElement(), parsed);

		assertEquals(original.getKinectId(), parsed.getKinectId(), 0.0001);
		assertTrue(original.getCoM().equals(parsed.getCoM()));
		assertTrue(original.getTorso().equals(parsed.getTorso()));
		assertEquals(original.isSkeleton(), parsed.isSkeleton());

	}

	@Test
	public void fileCompatibility() throws Exception {

		Builder parser = new Builder();
		Document doc = parser.build(TestUtils.makeTestFileName("Body.xml"));

		Body body = new Body();
		Body.fromElement(doc.getRootElement(), body);

		assertEquals(doc.getRootElement().getLocalName(), Body.getBaseTag());
		assertEquals("test", body.getGenerator());
		assertEquals(-1, body.getKinectId(), 0.0001);
		assertTrue(body.getCoM().equals(new Point3D(12,12,81,LengthUnit.MILLIMETER)));
		// because skeleton not active
		assertEquals(0.0, body.getTorso().getX(LengthUnit.MILLIMETER), 0.0001);
		assertEquals(0.0, body.getTorso().getY(LengthUnit.MILLIMETER), 0.0001);
		assertEquals(0.0, body.getTorso().getZ(LengthUnit.MILLIMETER), 0.0001);
		assertEquals(false, body.isSkeleton());

	}

}
