/*
 * This file is part of Bielefeld Type Library (BTL).
 * 
 * Copyright(c) Frederic Siepmann http://opensource.cit-ec.de/projects/btl
 * 
 * This file may be licensed under the terms of of the GNU Lesser General Public
 * License Version 3 (the ``LGPL''), or (at your option) any later version.
 * 
 * Software distributed under the License is distributed on an ``AS IS'' basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the LGPL for the
 * specific language governing rights and limitations.
 * 
 * You should have received a copy of the LGPL along with this program. If not,
 * go to http://www.gnu.org/licenses/lgpl.html or write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 * 
 * The development of this software was supported by the Excellence Cluster EXC
 * 277 Cognitive Interaction Technology. The Excellence Cluster EXC 277 is a
 * grant of the Deutsche Forschungsgemeinschaft (DFG) in the context of the
 * German Excellence Initiative.
 * 
 * Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman
 * Köster, Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling, Denis
 * Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
 */
package de.unibi.airobots.btl.data.speechrec;

import static org.junit.Assert.assertEquals;
import nu.xom.Builder;
import nu.xom.Document;
import nu.xom.Element;

import org.apache.log4j.Logger;
import org.junit.Test;

import de.unibi.airobots.btl.TestUtils;
import de.unibi.airobots.btl.Type;
import de.unibi.airobots.btl.data.common.Timestamp;
import de.unibi.airobots.btl.data.speechrec.GPSRAction.GPSRParameter;

/**
 * Test cases for {@link Type}.
 * 
 * @author sjebbara
 */
public class UtterancePartTest {

	private Logger logger = Logger.getLogger(getClass());

	@Test
	public void selfCompatibility() {

		UtterancePart actual = new UtterancePart();
		final long timestamp = System.currentTimeMillis();
		actual.setTimestamp(timestamp);
		actual.setGenerator("test");
		actual.setWord("auto");
		actual.setBegin(1);
		actual.setId(2);
		actual.setEnd(3);
		actual.setAcousticScore(4.567);
		actual.setLmScore(5.678);
		actual.setCombinedScore(6.789);

		Document doc = new Document(new Element(UtterancePart.getBaseTag()));
		actual.fillInto(doc.getRootElement());
		logger.info(doc.toXML());

		UtterancePart parsed = new UtterancePart();
		UtterancePart.fromElement(doc.getRootElement(), parsed);

		assertEquals(actual, parsed);
	}

	@Test
	public void fileCompatibility() throws Exception {

		Builder parser = new Builder();
		Document doc = parser.build(TestUtils
				.makeTestFileName("UtterancePart.xml"));

		UtterancePart parsed = new UtterancePart();
		UtterancePart.fromElement(doc.getRootElement(), parsed);
		assertEquals(doc.getRootElement().getLocalName(),
				UtterancePart.getBaseTag());

		assertEquals("test", parsed.getGenerator());
		assertEquals(new Timestamp(12345, 67890), parsed.getTimestamp());
		assertEquals(1, parsed.getBegin());
		assertEquals(2, parsed.getId());
		assertEquals(3, parsed.getEnd());
		assertEquals(4.567, parsed.getAcousticScore(), 0);
		assertEquals(5.678, parsed.getLmScore(), 0);
		assertEquals(6.789, parsed.getCombinedScore(), 0);
	}

}
